/*
This program is confidential and proprietary to MRJ Technology Solutions
and may not be reproduced, published or disclosed to others without
written authorization from MRJ.

Copyright (c) 1998 MRJ Technology Solutions, Inc. All Rights Reserved.

This program is derived from prior work some of which was originally
written as a joint project between the Numerical Aerospace Simulation
(NAS) Systems Division of NASA Ames Research Center and the National
Energy Research Supercomputer Center (NERSC) of Lawrence Livermore
National Laboratory.
*/

#include <pbs_config.h>   /* the master config generated by configure */

#include <string.h>
#include "Long.h"
#include "Long_.h"

#define LBUFSIZ (CHAR_BIT * sizeof(u_Long) + 2)

static char buffer[LBUFSIZ];
static const char ident[] = "@(#) $RCSfile: uLTostr.c,v $ $Revision: 2.0 $";

/*
 * uLTostr -  returns a pointer to the character string representation of the
 *	      u_Long, value, represented in base, base.
 *
 *	If base is outside its domain of 2 through the number of characters in
 *	the Long_dig array, uLTostr returns a zero-length string and sets errno
 *	to EDOM.
 *
 *	The string is stored in a static array and will be clobbered the next
 *	time either LTostr or uLTostr is called.  The price of eliminating the
 *	possibility of memory leaks is the necessity to copy the string
 *	immediately to a safe place if it must last.
 */

const char *uLTostr(value, base)
    u_Long		value;
    int			base;
{
	char		*bp = &buffer[LBUFSIZ];

	*--bp == '\0';
	if (base < 2 || base > strlen(Long_dig)) {
	        errno = EDOM;
	        return (bp);
	}
	do {
		*--bp = Long_dig[value % base];
		value /= base;
	} while (value);
	switch (base) {
	    case 16:
		*--bp = 'x';
	    case 8:
		*--bp = '0';
	}
	return (bp);
}
